@@ -20,16 +20,16 @@
 #ifndef GCONF_XML_CACHE_H
 #define GCONF_XML_CACHE_H
 
-#include <gconf/gconf.h>
+#include "gconf/gconf.h"
 #include <libxml/tree.h>
 #include "xml-dir.h"
 
 typedef struct _Cache Cache;
 
-Cache*   cache_new        (const gchar  *root_dir,
+Cache*   cache_get        (const gchar  *root_dir,
                            guint         dir_mode,
                            guint         file_mode);
-void     cache_destroy    (Cache        *cache);
+void     cache_unref      (Cache        *cache);
 gboolean cache_sync       (Cache        *cache,
                            GError      **err);
 void     cache_clean      (Cache        *cache,
@@ -39,4 +39,7 @@ Dir*     cache_lookup     (Cache        *cache,
                            gboolean      create_if_missing,
                            GError      **err);
 
+void xml_test_cache (void);
+
 #endif
+
