@@ -1639,6 +1639,13 @@ logfile_save (void)
       goto out;
     }
 
+  if (fsync (fd) < 0)
+    {
+      gconf_log (GCL_WARNING,
+                 _("Could not flush saved state file '%s' to disk: %s"),
+                 tmpfile, g_strerror (errno));
+    }
+
   if (close (fd) < 0)
     {
       gconf_log (GCL_WARNING,
